AppcareFlutterMacOS class
Stub registration class for macOS on platforms without dart:io.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onConnectivityChanged
→ Stream<
bool> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canAuthenticateBiometrics(
) → Future< bool> -
inherited
-
checkConnectivity(
) → Future< bool> -
inherited
-
checkForUpdate(
) → Future< Map< String, dynamic> > -
inherited
-
clearAppBadge(
) → Future< bool> -
inherited
-
getAppBaseInfo(
) → Future< Map< String, dynamic> > -
inherited
-
getAppInfo(
) → Future< Map< String, String> > -
inherited
-
getBatteryInfo(
) → Future< Map< String, dynamic> > -
inherited
-
getCurrentLocation(
) → Future< Map< String, double> ?> -
inherited
-
getDeviceInfo(
) → Future< Map< String, dynamic> > -
inherited
-
getDeviceLocale(
) → Future< String> -
inherited
-
getFontScale(
) → Future< double> -
inherited
-
getLocalIpAddress(
) → Future< String?> -
inherited
-
getNetworkType(
) → Future< String> -
inherited
-
getScreenBrightness(
) → Future< double> -
inherited
-
getStorageInfo(
) → Future< Map< String, int> > -
inherited
-
getStoragePath(
) → Future< String?> -
inherited
-
getThermalStatus(
) → Future< String> -
inherited
-
getVolume(
) → Future< double> -
inherited
-
getWifiSignalStrength(
) → Future< int> -
inherited
-
isAppInstalled(
String packageNameOrScheme) → Future< bool> -
inherited
-
isAutomaticTime(
) → Future< bool> -
inherited
-
isDarkMode(
) → Future< bool> -
inherited
-
isDeviceFaceDown(
) → Future< bool> -
inherited
-
isLowMemory(
) → Future< bool> -
inherited
-
isMockLocation(
) → Future< bool> -
inherited
-
isMuted(
) → Future< bool> -
inherited
-
isScreenBeingRecorded(
) → Future< bool> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openDialer(
String phoneNumber) → Future< bool> -
inherited
-
openEmail(
String email, {String? subject}) → Future< bool> -
inherited
-
openStore(
{String? url}) → Future< bool> -
inherited
-
openUrl(
String url) → Future< bool> -
inherited
-
pingHost(
String host) → Future< int> -
inherited
-
playSystemBeep(
) → Future< bool> -
inherited
-
requestReview(
) → Future< bool> -
inherited
-
setAppBadgeCount(
int count) → Future< bool> -
inherited
-
setKeepScreenOn(
bool keepOn) → Future< bool> -
inherited
-
setScreenBrightness(
double brightness) → Future< bool> -
inherited
-
setScreenSecurity(
bool enable) → Future< bool> -
inherited
-
setVolume(
double level) → Future< bool> -
inherited
-
startUpdate(
) → Future< bool> -
inherited
-
toggleFlashlight(
) → Future< bool> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
turnFlashlightOff(
) → Future< bool> -
inherited
-
turnFlashlightOn(
) → Future< bool> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void -
Registers this class as the default instance of
AppcareFlutterPlatform.